pub struct AddAttachmentInfo(/* private fields */);Expand description
This structure is used to pass the attachment information to libCZIAPI, describing an attachment to be added to a CZI-file.
Implementations
Sourceimpl AddAttachmentInfo
impl AddAttachmentInfo
pub fn new( guid: [u8; 16], content_file_type: [u8; 8], name: [u8; 80], attachment_data: &[u8], ) -> Self
pub fn get_guid(&self) -> [u8; 16]
pub fn get_content_file_type(&self) -> [u8; 8]
pub fn get_name(&self) -> [u8; 80]
pub fn get_size_attachment_data(&self) -> u32
pub fn get_attachment_data(&self) -> Vec<u8> ⓘ
pub fn set_guid(&mut self, guid: [u8; 16])
pub fn set_content_file_type(&mut self, content_file_type: [u8; 8])
pub fn set_name(&mut self, name: [u8; 80])
pub fn set_attachment_data(&mut self, attachment_data: &[u8])