Struct AddSubBlockInfo

pub struct AddSubBlockInfo(/* private fields */);
This structure is used to pass the subblock information to libCZIAPI, describing a subblock to be added to a CZI-file.

Implementations

Source

impl AddSubBlockInfo

pub fn new( coordinate: Coordinate, m_index_valid: u8, m_index: i32, x: i32, y: i32, logical_width: i32, logical_height: i32, physical_width: i32, physical_height: i32, pixel_type: PixelType, compression_mode_raw: i32, data: &[u8], metadata: &[u8], attachment: &[u8], ) -> Self

pub fn get_coordinate(&self) -> Coordinate

pub fn get_m_index_valid(&self) -> u8

pub fn get_m_index(&self) -> i32

pub fn get_x(&self) -> i32

pub fn get_y(&self) -> i32

pub fn get_logical_width(&self) -> i32

pub fn get_logical_height(&self) -> i32

pub fn get_physical_width(&self) -> i32

pub fn get_physical_height(&self) -> i32

pub fn get_pixel_type(&self) -> Result<PixelType>

pub fn get_compression_mode_raw(&self) -> i32

pub fn get_size_data(&self) -> u32

pub fn get_data(&self) -> Vec<u8>

pub fn get_size_metadata(&self) -> u32

pub fn get_metadata(&self) -> Vec<u8>

pub fn get_size_attachment(&self) -> u32

pub fn get_attachment(&self) -> Vec<u8>

pub fn set_coordinate(&mut self, coordinate: Coordinate)

pub fn set_m_index_valid(&mut self, m_index_valid: u8)

pub fn set_m_index(&mut self, m_index: i32)

pub fn set_x(&mut self, x: i32)

pub fn set_y(&mut self, y: i32)

pub fn set_logical_width(&mut self, logical_width: i32)

pub fn set_logical_height(&mut self, logical_height: i32)

pub fn set_physical_width(&mut self, physical_width: i32)

pub fn set_physical_height(&mut self, physical_height: i32)

pub fn set_pixel_type(&mut self, pixel_type: PixelType)

pub fn set_compression_mode_raw(&mut self, compression_mode_raw: i32)

pub fn set_data(&mut self, data: &[u8])

pub fn set_metadata(&mut self, metadata: &[u8])

pub fn set_attachment(&mut self, attachment: &[u8])