pub struct AttachmentInfo(/* private fields */);Expand description
This structure contains the information about an attachment. Note that performance reasons we use a fixed-size array for the name. In the rare case that the name is too long to fit into the fixed-size array, the ‘overflow’ field is set to true. In this case, the name is truncated and the ‘overflow’ field is set to true. In addition, the field ‘name_in_case_of_overflow’ then contains the full text, allocated with ‘libCZI_AllocateString’ (and responsibility for releasing the memory is with the caller).
Implementations