pub struct Bitmap(/* private fields */);Expand description
bitmap object.
Implementations
Sourceimpl Bitmap
impl Bitmap
Sourcepub fn get_info(&self) -> Result<BitmapInfo, Error>
pub fn get_info(&self) -> Result<BitmapInfo, Error>
Get information about the specified bitmap object.
\param bitmap_object The bitmap object. \param [out] bitmap_info If successful, information about the bitmap object is put here.
\returns An error-code indicating success or failure of the operation.
Sourcepub fn lock(self) -> Result<LockedBitmap, Error>
pub fn lock(self) -> Result<LockedBitmap, Error>
Locks the bitmap object. Once the bitmap is locked, the pixel data can be accessed. Memory access to the pixel data must only occur while the bitmap is locked. The lock must be released by calling ‘libCZI_BitmapUnlock’. It is a fatal error if the bitmap is destroyed while still being locked. Calls to Lock and Unlock are counted, and they must be balanced.
\param bitmap_object The bitmap object. \param [out] lockInfo If successful, information about how to access the pixel data is put here.
\returns An error-code indicating success or failure of the operation.