Coordinate

Struct Coordinate 

pub struct Coordinate(/* private fields */);
This structure gives the coordinates (of a sub-block) for a set of dimension. The bit at position i in dimensions_valid indicates whether the coordinate for dimension i+1 is valid. So, bit 0 is corresponding to dimension 1 (=Z), bit 1 to dimension 2 (=C), and so on. In the fixed-sized array value, the coordinate for the dimensions is stored. The element at position 0 corresponds to the first valid dimension, the element at position 1 to the second valid dimension, and so on. An example would be: dimensions_valid = 0b00000011, value = { 0, 2 }. This would mean that the dimension ‘Z’ is valid, and the coordinate for ‘Z’ is 0, and the dimension ‘C’ is valid, and the coordinate for ‘C’ is 2.

Implementations

Source

impl Coordinate

pub fn new(dimensions_valid: u32, value: [i32; 9]) -> Self

pub fn get_dimensions_valid(&self) -> u32

pub fn get_value(&self) -> [i32; 9]

pub fn set_dimensions_valid(&mut self, dimensions_valid: u32)

pub fn set_value(&mut self, value: [i32; 9])