pub struct DimBounds(/* private fields */);Expand description
This structure gives the bounds for a set of dimensions.
The bit at position i in dimensions_valid indicates whether the interval for dimension i+1 is valid. So, bit 0
is corresponding to dimension 1 (=Z), bit 1 to dimension 2 (=C), and so on.
In the fixed-sized arrays start and size, the start and size values for the dimensions are stored. The elements at
position 0 corresponds to the first valid dimension, the element at position 1 to the second valid dimension, and so on.
An example would be: dimensions_valid = 0b00000011, start = { 0, 2 }, size = { 5, 6 }. This would mean that the
dimension ‘Z’ is valid, and the interval is [0, 5], and the dimension ‘C’ is valid, and the interval is [2, 8].
Implementations
Sourceimpl DimBounds
impl DimBounds
pub fn new(dimensions_valid: u32, start: [i32; 9], size: [i32; 9]) -> Self
pub fn get_dimensions_valid(&self) -> u32
pub fn get_start(&self) -> [i32; 9]
pub fn get_size(&self) -> [i32; 9]
pub fn set_dimensions_valid(&mut self, dimensions_valid: u32)
pub fn set_start(&mut self, start: [i32; 9])
pub fn set_size(&mut self, size: [i32; 9])