pub struct ExternalInputStreamStruct(/* private fields */);Expand description
This structure contains information about externally provided functions for reading data from an input stream, and it is used to construct a stream-object to be used with libCZI. Note on lifetime: The function pointers must remain valid until the function ‘close_function’ is called. The lifetime may extend beyond calling the ‘libCZI_ReleaseInputStream’ function for the corresponding stream-object.
Implementations
Sourceimpl ExternalInputStreamStruct
impl ExternalInputStreamStruct
Sourcepub fn get_opaque_handle1(&self) -> u64
pub fn get_opaque_handle1(&self) -> u64
A user parameter which is passed to the callback function.
Sourcepub fn get_opaque_handle2(&self) -> u64
pub fn get_opaque_handle2(&self) -> u64
A user parameter which is passed to the callback function.
pub fn set_opaque_handle1(&mut self, handle: u64)
pub fn set_opaque_handle2(&mut self, handle: u64)