pub struct IntRect(/* private fields */);Expand description
This structure describes a rectangle, given by its top-left corner and its width and height.
Implementations
Sourceimpl IntRect
This structure describes a rectangle, given by its top-left corner and its width and height.
impl IntRect
This structure describes a rectangle, given by its top-left corner and its width and height.
pub fn new(x: i32, y: i32, w: i32, h: i32) -> Self
pub fn get_x(&self) -> i32
pub fn get_y(&self) -> i32
pub fn get_w(&self) -> i32
pub fn get_h(&self) -> i32
pub fn set_x(&mut self, x: i32)
pub fn set_y(&mut self, y: i32)
pub fn set_w(&mut self, w: i32)
pub fn set_h(&mut self, h: i32)