pub struct LibCZIBuildInformation(/* private fields */);Expand description
This struct gives information about the build of the libCZIApi-library. Note that all strings must be freed by the caller (using libCZI_Free).
Implementations
Sourceimpl LibCZIBuildInformation
impl LibCZIBuildInformation
Sourcepub fn get() -> Result<LibCZIBuildInformation, Error>
pub fn get() -> Result<LibCZIBuildInformation, Error>
Get information about the build of the libCZIApi-library.
\param [out] build_info If successful, the build information is put here. Note that all strings must be freed by the caller (using ‘libCZI_Free’).
\returns An error-code indicating success or failure of the operation.
Sourceimpl LibCZIBuildInformation
impl LibCZIBuildInformation
pub fn get_compiler_information(&self) -> Cow<'_, str>
pub fn get_repository_url(&self) -> Cow<'_, str>
pub fn get_repository_branch(&self) -> Cow<'_, str>
pub fn get_repository_tag(&self) -> Cow<'_, str>