pub struct LibCZIVersionInfo(/* private fields */);Expand description
This struct contains the version information of the libCZIApi-library. For versioning libCZI, SemVer2 (https://semver.org/) is used. Note that the value of the tweak version number does not have a meaning (as far as SemVer2 is concerned).
Implementations
Sourceimpl LibCZIVersionInfo
impl LibCZIVersionInfo
Sourcepub fn get_lib_czi_version_info() -> Result<LibCZIVersionInfo, Error>
pub fn get_lib_czi_version_info() -> Result<LibCZIVersionInfo, Error>
Get version information about the libCZIApi-library.
\param [out] version_info If successful, the version information is put here.
\returns An error-code indicating success or failure of the operation.