pub struct MetadataSegment(/* private fields */);Expand description
metadata segment object.
Implementations
Sourceimpl MetadataSegment
impl MetadataSegment
Sourcepub fn get_metadata_as_xml(&self) -> Result<MetadataAsXml, Error>
pub fn get_metadata_as_xml(&self) -> Result<MetadataAsXml, Error>
Get the XML-metadata information from the specified metadata-segment object. Note that the XML-metadata is returned as a pointer to the data (in the ‘data’ field of the ‘MetadataAsXmlInterop’ structure), which must be freed by the caller using ‘libCZI_Free’.
\param metadata_segment_object The metadata segment object. \param [out] metadata_as_xml_interop If successful, the XML-metadata information is put here.
\returns An error-code indicating success or failure of the operation.
Sourcepub fn get_czi_document_info(&self) -> Result<CziDocumentInfo, Error>
pub fn get_czi_document_info(&self) -> Result<CziDocumentInfo, Error>
Create a CZI-document-information object from the specified metadata-segment object.
\param metadata_segment_object The metadata segment object. \param [in,out] czi_document_info If successful, a handle to the newly created CZI-document-info object is put here.
\returns An error-code indicating success or failure of the operation.