pub struct ReaderOpenInfo(/* private fields */);Expand description
This structure gather the information needed to create a reader object.
Implementations
Sourceimpl ReaderOpenInfo
This structure gather the information needed to create a reader object.
impl ReaderOpenInfo
This structure gather the information needed to create a reader object.
pub fn new(stream: &InputStream) -> Self
pub fn get_stream(&self) -> InputStream