SingleChannelScalingTileAccessor

Struct SingleChannelScalingTileAccessor 

pub struct SingleChannelScalingTileAccessor(/* private fields */);
single-channel-scaling-tile-accessor.

Implementations

Source

impl SingleChannelScalingTileAccessor

pub fn calc_size(&self, roi: IntRect, zoom: f32) -> Result<IntSize, Error>

Gets the size information of the specified tile accessor based on the region of interest and zoom factor.

\param accessor_object Handle to the tile accessor object for which the size is to be calculated. This object is responsible for managing the access to the tiles within the specified plane. \param roi The region of interest that defines the region of interest within the plane for which the size is to be calculated. \param zoom A floating-point value representing the zoom factor. \param size [out] The size of the tile accessor. It contains width and height information.

\returns An error-code indicating success or failure of the operation.

pub fn get( &self, coordinate: Coordinate, roi: IntRect, zoom: f32, options: AccessorOptions, ) -> Result<Bitmap, Error>

Gets the tile bitmap of the specified plane and the specified roi with the specified zoom factor.

\param accessor_object Handle to the tile accessor object. This object is responsible for managing the access to the tiles within the specified plane. \param coordinate Pointer to a CoordinateInterop structure that specifies the coordinates within the plane from which the tile bitmap is to be retrieved. \param roi The region of interest that defines within the plane for which the tile bitmap is requested. \param zoom A floating-point value representing the zoom factor. \param options A pointer to an AccessorOptionsInterop structure that may contain additional options for accessing the tile bitmap. \param bitmap_object [out] If the operation is successful, the created bitmap object will be put here.

\returns An error-code indicating success or failure of the operation.

pub fn release(&self) -> Result<(), Error>

Release the specified accessor object.

\param accessor_object The accessor object.

\returns An error-code indicating success or failure of the operation.