libCZI_AllocateMemory

Function libCZI_AllocateMemory 

pub unsafe extern "C" fn libCZI_AllocateMemory(
    size: c_ulong,
    data: *mut *mut c_void,
) -> LibCZIApiErrorCode
Allocate memory of the specified size.

\param size The size of the memory block to be allocated in bytes. \param [out] data If successful, a pointer to the allocated memory is put here. The memory must be freed using ‘libCZI_Free’.

\returns An error-code indicating success or failure of the operation.