libCZI_BitmapCopyTo

Function libCZI_BitmapCopyTo 

pub unsafe extern "C" fn libCZI_BitmapCopyTo(
    bitmap_object: BitmapObjectHandle,
    width: c_uint,
    height: c_uint,
    pixel_type: c_int,
    stride: c_uint,
    ptr: *mut c_void,
) -> LibCZIApiErrorCode
Copy the pixel data from the specified bitmap object to the specified memory buffer. The specified destination bitmap must have same width, height and pixel type as the source bitmap.

\param bitmap_object The bitmap object. \param width The width of the destination bitmap. \param height The height of the destination bitmap. \param pixel_type The pixel type. \param stride The stride (given in bytes). \param [out] ptr Pointer to the memory location where the bitmap is to be copied to.

\returns A LibCZIApiErrorCode.