libCZI_BitmapLock

Function libCZI_BitmapLock 

pub unsafe extern "C" fn libCZI_BitmapLock(
    bitmap_object: BitmapObjectHandle,
    lockInfo: *mut BitmapLockInfoInterop,
) -> LibCZIApiErrorCode
Locks the bitmap object. Once the bitmap is locked, the pixel data can be accessed. Memory access to the pixel data must only occur while the bitmap is locked. The lock must be released by calling ‘libCZI_BitmapUnlock’. It is a fatal error if the bitmap is destroyed while still being locked. Calls to Lock and Unlock are counted, and they must be balanced.

\param bitmap_object The bitmap object. \param [out] lockInfo If successful, information about how to access the pixel data is put here.

\returns An error-code indicating success or failure of the operation.