libCZI_CreateInputStream

Function libCZI_CreateInputStream 

pub unsafe extern "C" fn libCZI_CreateInputStream(
    stream_class_name: *const c_char,
    creation_property_bag: *const c_char,
    stream_identifier: *const c_char,
    stream_object: *mut InputStreamObjectHandle,
) -> LibCZIApiErrorCode
Create an input stream object of the specified type, using the specified JSON-formatted property bag and the specified file identifier as input.

\param stream_class_name Name of the stream class to be instantiated. \param creation_property_bag JSON formatted string (containing additional parameters for the stream creation) in UTF8-encoding. \param stream_identifier The filename (or, more generally, a URI of some sort) identifying the file to be opened in UTF8-encoding. \param [out] stream_object If successful, a handle representing the newly created stream object is put here.

\returns An error-code that indicates whether the operation is successful or not.