pub unsafe extern "C" fn libCZI_CreateInputStreamFromExternal(
external_input_stream_struct: *const ExternalInputStreamStructInterop,
stream_object: *mut InputStreamObjectHandle,
) -> LibCZIApiErrorCodeExpand description
Create an input stream object which is using externally provided functions for operation and reading the data. Please refer to the documentation of ‘ExternalInputStreamStructInterop’ for more information.
\param external_input_stream_struct Structure containing the information about the externally provided functions. \param [out] stream_object If successful, the handle to the newly created input stream object is put here.
\returns An error-code indicating success or failure of the operation.