pub unsafe extern "C" fn libCZI_CreateOutputStreamFromExternal(
external_output_stream_struct: *const ExternalOutputStreamStructInterop,
output_stream_object: *mut OutputStreamObjectHandle,
) -> LibCZIApiErrorCodeExpand description
Create an output stream object which is using externally provided functions for operation and writing the data. Please refer to the documentation of ‘ExternalOutputStreamStructInterop’ for more information.
\param external_output_stream_struct Structure containing the information about the externally provided functions. \param [out] output_stream_object If successful, the handle to the newly created output stream object is put here.
\returns An error-code indicating success or failure of the operation.