libCZI_CreateReader

Function libCZI_CreateReader 

pub unsafe extern "C" fn libCZI_CreateReader(
    reader_object: *mut CziReaderObjectHandle,
) -> LibCZIApiErrorCode
Create a new CZI-reader object.

\param [out] reader_object If the operation is successful, a handle to the newly created reader object is put here.

\returns An error-code indicating success or failure of the operation.