libCZI_CreateWriter

Function libCZI_CreateWriter 

pub unsafe extern "C" fn libCZI_CreateWriter(
    writer_object: *mut CziWriterObjectHandle,
    options: *const c_char,
) -> LibCZIApiErrorCode
Create a writer object for authoring a document in CZI-format. The options string is a JSON-formatted string, here is an example: \code { “allow_duplicate_subblocks” : true } \endcode

\param [out] writer_object If the operation is successful, a handle to the newly created writer object is put here. \param options A JSON-formatted zero-terminated string (in UTF8-encoding) containing options for the writer creation.

\returns An error-code indicating success or failure of the operation.