libCZI_Free

Function libCZI_Free 

pub unsafe extern "C" fn libCZI_Free(data: *mut c_void)
Release the memory - this function is to be used for freeing memory allocated by the libCZIApi-library (and returned to the caller).

\param data Pointer to the memory to be freed.