libCZI_GetLibCZIBuildInformation

Function libCZI_GetLibCZIBuildInformation 

pub unsafe extern "C" fn libCZI_GetLibCZIBuildInformation(
    build_info: *mut LibCZIBuildInformationInterop,
) -> LibCZIApiErrorCode
Get information about the build of the libCZIApi-library.

\param [out] build_info If successful, the build information is put here. Note that all strings must be freed by the caller (using ‘libCZI_Free’).

\returns An error-code indicating success or failure of the operation.