libCZI_GetStreamClassInfo

Function libCZI_GetStreamClassInfo 

pub unsafe extern "C" fn libCZI_GetStreamClassInfo(
    index: c_int,
    input_stream_class_info: *mut InputStreamClassInfoInterop,
) -> LibCZIApiErrorCode
Get information about the stream class at the specified index.

\param index Zero-based index of the stream class to query information about. \param [out] input_stream_class_info If successful, information about the stream class is put here. Note that the strings in the structure must be freed (by the caller) using ‘libCZI_Free’.

\returns An error-code indicating success or failure of the operation.