libCZI_MetadataSegmentGetMetadataAsXml

Function libCZI_MetadataSegmentGetMetadataAsXml 

pub unsafe extern "C" fn libCZI_MetadataSegmentGetMetadataAsXml(
    metadata_segment_object: MetadataSegmentObjectHandle,
    metadata_as_xml_interop: *mut MetadataAsXmlInterop,
) -> LibCZIApiErrorCode
Get the XML-metadata information from the specified metadata-segment object. Note that the XML-metadata is returned as a pointer to the data (in the ‘data’ field of the ‘MetadataAsXmlInterop’ structure), which must be freed by the caller using ‘libCZI_Free’.

\param metadata_segment_object The metadata segment object. \param [out] metadata_as_xml_interop If successful, the XML-metadata information is put here.

\returns An error-code indicating success or failure of the operation.