pub unsafe extern "C" fn libCZI_ReaderGetStatisticsEx(
reader_object: CziReaderObjectHandle,
statistics: *mut SubBlockStatisticsInteropEx,
number_of_per_channel_bounding_boxes: *mut c_int,
) -> LibCZIApiErrorCodeExpand description
Get extended statistics about the sub-blocks in the CZI-document. This function provides a more detailed version of the statistics, including the per-scene statistics. Note that the statistics is of variable size, and the semantic is as follows:
- On input, the argument ‘number_of_per_channel_bounding_boxes’ must point to an integer which describes the size of the argument ‘statistics’. This number gives how many elements the array ‘per_scenes_bounding_boxes’ in ‘SubBlockStatisticsInteropEx’ can hold. Only that number of per-scene information elements will be put into the ‘statistics’ structure at most, in any case.
- On output, the argument ‘number_of_per_channel_bounding_boxes’ will be set to the number of per-channel bounding boxes that were actually available.
- In the returned ‘SubBlockStatisticsInteropEx’ structure, the ‘number_of_per_scenes_bounding_boxes’ field will be set to the number of per-scene information that is put into this struct (which may be less than number of scenes that are available). So, the caller is expected to check the returned ‘number_of_per_channel_bounding_boxes’ to see how many per-channel bounding boxes are available. If this number is greater than the number of elements (given with the ‘number_of_per_scenes_bounding_boxes’ value in the ‘statistics’ structure), then the caller should allocate a larger ‘statistics’ structure and call this function again (with an increased ‘number_of_per_scenes_bounding_boxes’).
\param reader_object The reader object. \param [out] statistics If non-null, the statistics will be put here. \param [in,out] number_of_per_channel_bounding_boxes On input, it gives the number of elements that can be put into the ‘per_scenes_bounding_boxes’ array. On output, it gives the number of elements which are available.
\returns An error-code indicating success or failure of the operation.