pub unsafe extern "C" fn libCZI_ReaderReadAttachment(
reader_object: CziReaderObjectHandle,
index: c_int,
attachment_object: *mut AttachmentObjectHandle,
) -> LibCZIApiErrorCodeExpand description
Read the attachment with the specified index and create an attachment object representing it. If the specified index is invalid, then the returned attachment-object handle will have the value ‘kInvalidObjectHandle’. \param reader_object The reader object. \param index The index of the attachment to get. \param [out] attachment_object If successful and index is valid, a handle representing the attachment object is put here. If the index is invalid, then the handle will have the value ‘kInvalidObjectHandle’. \returns An error-code indicating success or failure of the operation.