libCZI_ReleaseOutputStream

Function libCZI_ReleaseOutputStream 

pub unsafe extern "C" fn libCZI_ReleaseOutputStream(
    output_stream_object: OutputStreamObjectHandle,
) -> LibCZIApiErrorCode
Release the specified output stream object. After this function is called, the handle is no longer valid. Note that calling this function will only decrement the usage count of the underlying object; whereas the object itself (and the resources it holds) will only be released when the usage count reaches zero.

\param output_stream_object The output stream object.

\returns An error-code indicating success or failure of the operation.