pub unsafe extern "C" fn libCZI_SingleChannelTileAccessorGet(
accessor_object: SingleChannelScalingTileAccessorObjectHandle,
coordinate: *const CoordinateInterop,
roi: *const IntRectInterop,
zoom: f32,
options: *const AccessorOptionsInterop,
bitmap_object: *mut BitmapObjectHandle,
) -> LibCZIApiErrorCodeExpand description
Gets the tile bitmap of the specified plane and the specified roi with the specified zoom factor.
\param accessor_object Handle to the tile accessor object. This object is responsible for managing the access to the tiles within the specified plane.
\param coordinate Pointer to a CoordinateInterop structure that specifies the coordinates within the plane from which the tile bitmap is to be retrieved.
\param roi The region of interest that defines within the plane for which the tile bitmap is requested.
\param zoom A floating-point value representing the zoom factor.
\param options A pointer to an AccessorOptionsInterop structure that may contain additional options for accessing the tile bitmap.
\param bitmap_object [out] If the operation is successful, the created bitmap object will be put here.
\returns An error-code indicating success or failure of the operation.