pub unsafe extern "C" fn libCZI_WriterClose(
writer_object: CziWriterObjectHandle,
) -> LibCZIApiErrorCodeExpand description
Finalizes the CZI (i.e. writes out the final directory-segments) and closes the file. Note that this method must be called explicitly in order to get a valid CZI - calling ‘libCZI_ReleaseWriter’ without a prior call to this method will close the file immediately without finalization.
\param writer_object Handle to the writer object that is to be closed.
\returns An error-code indicating success or failure of the operation.