AccessorOptionsInterop

Struct AccessorOptionsInterop 

#[repr(C, packed(4))]
pub struct AccessorOptionsInterop { pub back_ground_color_r: f32, pub back_ground_color_g: f32, pub back_ground_color_b: f32, pub sort_by_m: bool, pub use_visibility_check_optimization: bool, pub additional_parameters: *const c_char, }
This structure is used to pass the accessor options to libCZIAPI.

Fields

back_ground_color_r: f32

The red component of the background color. If the destination bitmap is a grayscale-type, then the mean from R, G and B is calculated and multiplied with the maximum pixel value (of the specific pixeltype). If it is an RGB-color type, then R, G and B are separately multiplied with the maximum pixel value. If any of R, G or B is NaN, then the background is not cleared.

back_ground_color_g: f32

The green component of the background color. If the destination bitmap is a grayscale-type, then the mean from R, G and B is calculated and multiplied with the maximum pixel value (of the specific pixeltype). If it is an RGB-color type, then R, G and B are separately multiplied with the maximum pixel value. If any of R, G or B is NaN, then the background is not cleared.

back_ground_color_b: f32

The blue component of the background color. If the destination bitmap is a grayscale-type, then the mean from R, G and B is calculated and multiplied with the maximum pixel value (of the specific pixeltype). If it is an RGB-color type, then R, G and B are separately multiplied with the maximum pixel value. If any of R, G or B is NaN, then the background is not cleared.

sort_by_m: bool

If true, then the tiles are sorted by their M-index (tile with highest M-index will be ‘on top’). Otherwise, the Z-order is arbitrary.

use_visibility_check_optimization: bool

If true, then the tile-visibility-check-optimization is used. When doing the multi-tile composition, all relevant tiles are checked whether they are visible in the destination bitmap. If a tile is not visible, then the corresponding sub-block is not read. This can speed up the operation considerably. The result is the same as without this optimization - i.e. there should be no reason to turn it off besides potential bugs.

additional_parameters: *const c_char

Additional parameters for the accessor.