#[repr(C, packed(4))]pub struct AddAttachmentInfoInterop {
pub guid: [c_uchar; 16],
pub contentFileType: [c_uchar; 8],
pub name: [c_uchar; 80],
pub size_attachment_data: c_uint,
pub attachment_data: *const c_void,
}Expand description
This structure is used to pass the attachment information to libCZIAPI, describing an attachment to be added to a CZI-file.
Fields
guid: [c_uchar; 16]< The GUID of the attachment.
contentFileType: [c_uchar; 8]< The content file type.
name: [c_uchar; 80]< The name of the attachment.
size_attachment_data: c_uint< The size of the attachment data (in bytes).
attachment_data: *const c_void< Pointer to the attachment data.