CompositionChannelInfoInterop

Struct CompositionChannelInfoInterop 

#[repr(C, packed(4))]
pub struct CompositionChannelInfoInterop { pub weight: f32, pub enable_tinting: c_uchar, pub tinting_color_r: c_uchar, pub tinting_color_g: c_uchar, pub tinting_color_b: c_uchar, pub black_point: f32, pub white_point: f32, pub look_up_table_element_count: c_int, pub ptr_look_up_table: *mut c_uchar, }
This structure gathers all information about a channel for the purpose of multi-channel-composition.

Fields

weight: f32

< The weight of the channel in the composition.

enable_tinting: c_uchar

True if tinting is enabled for this channel (in which case the tinting member is to be examined), false if no tinting is to be applied (the tinting member is then not used).

tinting_color_r: c_uchar

The tinting color (only examined if enableTinting is true). This is the red-component.

tinting_color_g: c_uchar

The tinting color (only examined if enableTinting is true). This is the green-component.

tinting_color_b: c_uchar

The tinting color (only examined if enableTinting is true). This is the blue-component.

black_point: f32

The black point - it is a float between 0 and 1, where 0 corresponds to the lowest pixel value (of the pixel-type for the channel) and 1 to the highest pixel value (of the pixel-type of this channel). All pixel values below the black point are mapped to 0.

white_point: f32

The white point - it is a float between 0 and 1, where 0 corresponds to the lowest pixel value (of the pixel-type for the channel) and 1 to the highest pixel value (of the pixel-type of this channel). All pixel value above the white pointer are mapped to the highest pixel value.

look_up_table_element_count: c_int

Number of elements in the look-up table. If 0, then the look-up table is not used. If this channelInfo applies to a Gray8/Bgr24-channel, then the size of the look-up table must be 256. In case of a Gray16/Bgr48-channel, the size must be 65536. \remark If a look-up table is provided, then \c blackPoint and \c whitePoint are not used anymore .

ptr_look_up_table: *mut c_uchar

The pointer to the look-up table. If the property ‘look_up_table_element_count’ is <> 0, then this pointer must be valid.