CoordinateInterop

Struct CoordinateInterop 

#[repr(C)]
pub struct CoordinateInterop { pub dimensions_valid: c_uint, pub value: [c_int; 9], }
This structure gives the coordinates (of a sub-block) for a set of dimension. The bit at position i in dimensions_valid indicates whether the coordinate for dimension i+1 is valid. So, bit 0 is corresponding to dimension 1 (=Z), bit 1 to dimension 2 (=C), and so on. In the fixed-sized array value, the coordinate for the dimensions is stored. The element at position 0 corresponds to the first valid dimension, the element at position 1 to the second valid dimension, and so on. An example would be: dimensions_valid = 0b00000011, value = { 0, 2 }. This would mean that the dimension ‘Z’ is valid, and the coordinate for ‘Z’ is 0, and the dimension ‘C’ is valid, and the coordinate for ‘C’ is 2.

Fields

dimensions_valid: c_uint

< Bitfield indicating which dimensions are valid. Bit-position i corresponds to dimension i+1.

value: [c_int; 9]

< The coordinate values, the element 0 corresponds the first set flag in dimensions_valid and so on.