#[repr(C)]pub struct DimBoundsInterop {
pub dimensions_valid: c_uint,
pub start: [c_int; 9],
pub size: [c_int; 9],
}Expand description
This structure gives the bounds for a set of dimensions.
The bit at position i in dimensions_valid indicates whether the interval for dimension i+1 is valid. So, bit 0
is corresponding to dimension 1 (=Z), bit 1 to dimension 2 (=C), and so on.
In the fixed-sized arrays start and size, the start and size values for the dimensions are stored. The elements at
position 0 corresponds to the first valid dimension, the element at position 1 to the second valid dimension, and so on.
An example would be: dimensions_valid = 0b00000011, start = { 0, 2 }, size = { 5, 6 }. This would mean that the
dimension ‘Z’ is valid, and the interval is [0, 5], and the dimension ‘C’ is valid, and the interval is [2, 8].
Fields
dimensions_valid: c_uint< Bitfield indicating which dimensions are valid. Bit-position i corresponds to dimension i+1.
start: [c_int; 9]< The start values, the element 0 corresponds the first set flag in dimensions_valid and so on.
size: [c_int; 9]< The size values, the element 0 corresponds the first set flag in dimensions_valid and so on.