#[repr(C, packed(4))]pub struct InputStreamClassInfoInterop {
pub name: *mut c_char,
pub description: *mut c_char,
}Fields
name: *mut c_char< The name of the input stream class. This is a free-form string. This string must be freed by the caller (using libCZI_Free).
description: *mut c_char< The description of the input stream class. This is a free-form string. This string must be freed by the caller (using libCZI_Free).