#[repr(C, packed(4))]pub struct LibCZIBuildInformationInterop {
pub compilerIdentification: *mut c_char,
pub repositoryUrl: *mut c_char,
pub repositoryBranch: *mut c_char,
pub repositoryTag: *mut c_char,
}Expand description
This struct gives information about the build of the libCZIApi-library. Note that all strings must be freed by the caller (using libCZI_Free).
Fields
compilerIdentification: *mut c_char< If non-null, the compiler identification. This is a free-form string. This string must be freed by the caller (using libCZI_Free).
repositoryUrl: *mut c_char< If non-null, the URL of the repository. This string must be freed by the caller (using libCZI_Free).
repositoryBranch: *mut c_char< If non-null, the branch of the repository. This string must be freed by the caller (using libCZI_Free).
repositoryTag: *mut c_char< If non-null, the tag of the repository. This string must be freed by the caller (using libCZI_Free).