#[repr(C)]pub struct LibCZIVersionInfoInterop {
pub major: i32,
pub minor: i32,
pub patch: i32,
pub tweak: i32,
}Expand description
This struct contains the version information of the libCZIApi-library. For versioning libCZI, SemVer2 (https://semver.org/) is used. Note that the value of the tweak version number does not have a meaning (as far as SemVer2 is concerned).
Fields
major: i32< The major version number.
minor: i32< The minor version number.
patch: i32< The patch version number.
tweak: i32< The tweak version number.