#[repr(C, packed(4))]pub struct ReaderOpenInfoInterop {
pub streamObject: InputStreamObjectHandle,
}Expand description
This structure gather the information needed to create a reader object.
Fields
streamObject: InputStreamObjectHandle< The input stream object to use for opening the file.