#[repr(C, packed(4))]pub struct WriteMetadataInfoInterop {
pub size_metadata: c_uint,
pub metadata: *const c_void,
}Expand description
This structure is used to pass the metadata information to libCZIAPI.
Fields
size_metadata: c_uint< The size of the data pointed to by metadata.
metadata: *const c_void< Pointer to the metadata. This data is expected to be XML in UTF8-encoding.