pub type ChannelDisplaySettingsHandle = ObjectHandle;Expand description
Defines an alias representing the handle of a “channel display settings” object.
pub type ChannelDisplaySettingsHandle = ObjectHandle;Defines an alias representing the handle of a “channel display settings” object.