pub type DisplaySettingsHandle = ObjectHandle;Expand description
Defines an alias representing the handle of a “display settings” object.
pub type DisplaySettingsHandle = ObjectHandle;Defines an alias representing the handle of a “display settings” object.