pub type InputStreamObjectHandle = ObjectHandle;Expand description
Defines an alias representing the handle of an input stream object.
pub type InputStreamObjectHandle = ObjectHandle;Defines an alias representing the handle of an input stream object.