MemoryAllocationObjectHandle

Type Alias MemoryAllocationObjectHandle 

pub type MemoryAllocationObjectHandle = ObjectHandle;
Defines an alias representing the handle of a memory allocation object - which is “a pointer to a memory block”, which must be freed with ‘libCZI_Free’. TODO(JBL): this is not really used so far, should be removed I guess.