pub type MetadataSegmentObjectHandle = ObjectHandle;Expand description
Defines an alias representing the handle of a metadata segment object.
pub type MetadataSegmentObjectHandle = ObjectHandle;Defines an alias representing the handle of a metadata segment object.