pub type OutputStreamObjectHandle = ObjectHandle;Expand description
Defines an alias representing the handle of an output stream object.
pub type OutputStreamObjectHandle = ObjectHandle;Defines an alias representing the handle of an output stream object.