pub type SingleChannelScalingTileAccessorObjectHandle = ObjectHandle;Expand description
Defines an alias representing the handle of a single-channel-scaling-tile-accessor.
pub type SingleChannelScalingTileAccessorObjectHandle = ObjectHandle;Defines an alias representing the handle of a single-channel-scaling-tile-accessor.