Attachment

Struct Attachment 

pub struct Attachment(/* private fields */);
attachment object.

Implementations

Source

impl Attachment

pub fn get_info(&self) -> Result<AttachmentInfo, Error>

Get information about the specified attachment object. \param attachment_object The attachment object. \param [out] attachment_info Information about the attachment. \returns An error-code indicating success or failure of the operation.

pub fn get_raw_data(&self, size: i32) -> Result<(i32, Vec<u8>), Error>

Copy the raw data from the specified attachment object to the specified memory buffer. The value of the ‘size’ parameter on input is the size of the buffer pointed to by ‘data’. On output, the value of ‘size’ is the actual size of the data. At most the initial value of ‘size’ bytes are copied to the buffer. If the initial value of ‘size’ is zero (0) or ‘data’ is null, then no data is copied. \param attachment_object The attachment object. \param [in,out] size On input, the size of the memory block pointed to by ‘data’, on output the actual size of the available data. \param [out] data Pointer where the data is to be copied to. At most the initial content of ‘size’ bytes are copied.

\returns An error-code indicating success or failure of the operation.

pub fn release(&self) -> Result<(), Error>

Release the specified attachment object.

\param attachment_object The attachment object to be released.

\returns An error-code indicating success or failure of the operation.