pub struct CziDocumentInfo(/* private fields */);Expand description
document info object.
Implementations
Sourceimpl CziDocumentInfo
impl CziDocumentInfo
Sourcepub fn get_general_document_info(&self) -> Result<String, Error>
pub fn get_general_document_info(&self) -> Result<String, Error>
Get "general document information" from the specified czi-document information object. The information is returned as a JSON-formatted string. The JSON returned is an object, with the following possible key-value pairs: "name" : <name of the document>, type string "title" : <title of the document>, type string "user_name" : <user name>, type string "description" : <description>, type string "comment" : <comment>, type string "keywords" : <keyword1>,<keyword2>,…", type string "rating" : <rating>, type integer "creation_date" : <creation date>, type string, conforming to ISO 8601
\param czi_document_info The CZI-document-info object. \param [out] general_document_info_json If successful, the general document information is put here. Note that the data must be freed using ‘libCZI_Free’ by the caller.
\returns An error-code indicating success or failure of the operation.
Sourcepub fn get_scaling_info(&self) -> Result<ScalingInfo, Error>
pub fn get_scaling_info(&self) -> Result<ScalingInfo, Error>
Get scaling information from the specified czi-document information object. The information gives the size of an image pixels.
\param czi_document_info Handle to the CZI-document-info object from which the scaling information will be retrieved. \param [out] scaling_info_interop If successful, the scaling information is put here.
\returns An error-code indicating success or failure of the operation.
Sourcepub fn get_display_settings(&self) -> Result<DisplaySettings, Error>
pub fn get_display_settings(&self) -> Result<DisplaySettings, Error>
Get the display-settings from the document’s XML-metadata. The display-settings are returned in the form of an object, for which a handle is returned.
\param czi_document_info The CZI-document-info object. \param [in,out] display_settings_handle If successful, a handle to the display-settings object is put here.
\returns An error-code indicating success or failure of the operation.
Sourcepub fn get_dimension_info(&self, dimension_index: u32) -> Result<String, Error>
pub fn get_dimension_info(&self, dimension_index: u32) -> Result<String, Error>
Get the dimension information from the document’s XML-metadata. The information is returned as a JSON-formatted string.
\param czi_document_info Handle to the CZI-document-info object from which the dimension information will be retrieved. \param dimension_index Index of the dimension. \param [out] dimension_info_json If successful, the information is put here as JSON format. Note that the data must be freed using ‘libCZI_Free’ by the caller.
\returns An error-code indicating success or failure of the operation.