libCZI_CreateOutputStreamForFileUTF8

Function libCZI_CreateOutputStreamForFileUTF8 

pub unsafe extern "C" fn libCZI_CreateOutputStreamForFileUTF8(
    filename: *const c_char,
    overwrite: bool,
    output_stream_object: *mut OutputStreamObjectHandle,
) -> LibCZIApiErrorCode
Create an input stream object for a file identified by its filename, which is given as an UTF8 - encoded string.

\param filename Filename of the file which is to be opened (in UTF8 encoding). \param overwrite Indicates whether the file should be overwritten. \param [out] output_stream_object The output stream object that will hold the created stream.

\return An error-code that indicates whether the operation is successful or not. Non-positive values indicates successful, positive values indicates unsuccessful operation.