libCZI_CreateOutputStreamForFileWide

Function libCZI_CreateOutputStreamForFileWide 

pub unsafe extern "C" fn libCZI_CreateOutputStreamForFileWide(
    filename: *const u32,
    overwrite: bool,
    output_stream_object: *mut OutputStreamObjectHandle,
) -> LibCZIApiErrorCode
Create an output stream object for a file identified by its filename, which is given as a wide string. Note that wchar_t on Windows is 16-bit wide, and on Unix-like systems it is 32-bit wide.

\param filename Filename of the file which is to be opened (zero terminated wide string). Note that on Windows, this is a string with 16-bit code units, and on Unix-like systems it is typically a string with 32-bit code units. \param overwrite Indicates whether the file should be overwritten. \param [out] output_stream_object The output stream object that will hold the created stream.

\return An error-code that indicates whether the operation is successful or not. Non-positive values indicates successful, positive values indicates unsuccessful operation.