libCZI_ReaderGetStatisticsSimple

Function libCZI_ReaderGetStatisticsSimple 

pub unsafe extern "C" fn libCZI_ReaderGetStatisticsSimple(
    reader_object: CziReaderObjectHandle,
    statistics: *mut SubBlockStatisticsInterop,
) -> LibCZIApiErrorCode
Get statistics about the sub-blocks in the CZI-document. This function provides a simple version of the statistics, the information retrieved does not include the per-scene statistics.

\param reader_object The reader object. \param [out] statistics If non-null, the simple statistics will be put here.

\returns An error-code indicating success or failure of the operation.