pub unsafe extern "C" fn libCZI_SubBlockCreateBitmap(
sub_block_object: SubBlockObjectHandle,
bitmap_object: *mut BitmapObjectHandle,
) -> LibCZIApiErrorCodeExpand description
Create a bitmap object from the specified sub-block object. The bitmap object can be used to access the pixel data contained in the sub-block. If the subblock contains compressed data, then decompression will be performed in this call.
\param sub_block_object The sub-block object. \param [out] bitmap_object If successful, the handle to the newly created bitmap object is put here.
\returns An error-code indicating success or failure of the operation.