pub unsafe extern "C" fn libCZI_TryGetSubBlockInfoForIndex(
reader_object: CziReaderObjectHandle,
index: c_int,
sub_block_info_interop: *mut SubBlockInfoInterop,
) -> LibCZIApiErrorCodeExpand description
Get information about the sub-block with the specified index. The information is put into the ‘sub_block_info_interop’ structure. If the index is not valid, then the function returns ‘LibCZIApi_ErrorCode_IndexOutOfRange’.
\param reader_object The reader object. \param index The index of the attachment to query information for. \param [out] sub_block_info_interop If successful, the retrieved information is put here.
\returns An error-code indicating success or failure of the operation.