pub unsafe extern "C" fn libCZI_WriterCreate(
writer_object: CziWriterObjectHandle,
output_stream_object: OutputStreamObjectHandle,
parameters: *const c_char,
) -> LibCZIApiErrorCodeExpand description
Initializes the writer object with the specified output stream object. The options string is a JSON-formatted string, here is an example: \code { “file_guid” : “123e4567-e89b-12d3-a456-426614174000”, “reserved_size_attachments_directory” : 4096, “reserved_size_metadata_segment” : 50000, “minimum_m_index” : 0, “maximum_m_index” : 100 } \endcode
\param [out] writer_object If the operation is successful, a handle to the newly created writer object is put here. \param output_stream_object The output stream object to be used for writing the CZI data. \param parameters A JSON-formatted zero-terminated string (in UTF8-encoding) containing options for the writer initialization.
\returns An error-code indicating success or failure of the operation.