#[repr(C, packed(4))]pub struct AddSubBlockInfoInterop {Show 18 fields
pub coordinate: CoordinateInterop,
pub m_index_valid: c_uchar,
pub m_index: c_int,
pub x: c_int,
pub y: c_int,
pub logical_width: c_int,
pub logical_height: c_int,
pub physical_width: c_int,
pub physical_height: c_int,
pub pixel_type: c_int,
pub compression_mode_raw: c_int,
pub size_data: c_uint,
pub data: *const c_void,
pub stride: c_uint,
pub size_metadata: c_uint,
pub metadata: *const c_void,
pub size_attachment: c_uint,
pub attachment: *const c_void,
}Expand description
This structure is used to pass the subblock information to libCZIAPI, describing a subblock to be added to a CZI-file.
Fields
coordinate: CoordinateInterop< The subblock’s coordinate.
m_index_valid: c_uchar< Whether the field ‘mIndex’ is valid;
m_index: c_int< The M-index of the subblock.
x: c_int< The x-coordinate of the subblock.
y: c_int< The y-coordinate of the subblock.
logical_width: c_int< The logical with of the subblock (in pixels).
logical_height: c_int< The logical height of the subblock (in pixels).
physical_width: c_int< The physical with of the subblock (in pixels).
physical_height: c_int< The physical height of the subblock (in pixels).
pixel_type: c_int< The pixel type of the subblock.
compression_mode_raw: c_intThe compression-mode (applying to the subblock-data). If using a compressed format, the data passed in must be already compressed - the writer does not perform the compression.
size_data: c_uint< The size of the subblock’s data in bytes.
data: *const c_void< Pointer to the data to be put into the subblock.
stride: c_uintIf the compression mode is set to ‘Uncompressed’, then this is valid and the stride of the bitmap. In this case, the line-size of the bitmap is determined by the pixel-type and the physical_width. And size_data must be large enough to hold the bitmap-data, and is validated. In other cases (compression-mode is not ‘Uncompressed’), this field is ignored.
size_metadata: c_uint< The size of the subblock-metadata in bytes. If this is 0, then ptrSbBlkMetadata is not used (and no sub-block-metadata written).
metadata: *const c_void< Pointer to the subblock-metadata.
size_attachment: c_uint< The size of the subblock-attachment in bytes. If this is 0, then attachment is not used (and no sub-block-metadata written).
attachment: *const c_void< Pointer to the subblock-attachment.