AttachmentInfoInterop

Struct AttachmentInfoInterop 

#[repr(C, packed(4))]
pub struct AttachmentInfoInterop { pub guid: [c_uchar; 16], pub content_file_type: [c_uchar; 9], pub name: [c_char; 255], pub name_overflow: bool, pub name_in_case_of_overflow: *mut c_void, }
This structure contains the information about an attachment. Note that performance reasons we use a fixed-size array for the name. In the rare case that the name is too long to fit into the fixed-size array, the ‘overflow’ field is set to true. In this case, the name is truncated and the ‘overflow’ field is set to true. In addition, the field ‘name_in_case_of_overflow’ then contains the full text, allocated with ‘libCZI_AllocateString’ (and responsibility for releasing the memory is with the caller).

Fields

guid: [c_uchar; 16]

< The GUID of the attachment.

content_file_type: [c_uchar; 9]

< A null-terminated character array identifying the content of the attachment.

name: [c_char; 255]

< A zero-terminated string (in UTF8-encoding) identifying the content of the attachment.

name_overflow: bool

< True if the name is too long to fit into the ‘name’ field.

name_in_case_of_overflow: *mut c_void

< If ‘name_overflow’ is true, then this field contains the name (in UTF8-encoding and zero terminated) of the attachment. This memory must be freed using ‘libCZI_Free’.