#[repr(C)]pub struct SubBlockInfoInterop {
pub compression_mode_raw: c_int,
pub pixel_type: c_int,
pub coordinate: CoordinateInterop,
pub logical_rect: IntRectInterop,
pub physical_size: IntSizeInterop,
pub m_index: c_int,
}Expand description
This structure contains the information about a sub-block.
Fields
compression_mode_raw: c_int< The (raw) compression mode identification of the sub-block. This value is not interpreted, use “GetCompressionMode” to have it < converted to the CompressionMode-enumeration.
pixel_type: c_int< The pixel type of the bitmap contained in the sub-block.
coordinate: CoordinateInterop< The coordinate of the sub-block.
logical_rect: IntRectInterop< The rectangle where the bitmap (in this sub-block) is located (in the CZI-pixel-coordinate system).
physical_size: IntSizeInterop< The physical size of the bitmap of the sub-block (which may be different to the size of logicalRect).
m_index: c_int< The M-index. If this has the value of ‘numeric_limits<int32_t>::min()’, then the M-index is not valid.