#[repr(C)]pub struct SubBlockStatisticsInteropEx {
pub sub_block_count: c_int,
pub min_m_index: c_int,
pub max_m_index: c_int,
pub bounding_box: IntRectInterop,
pub bounding_box_layer0: IntRectInterop,
pub dim_bounds: DimBoundsInterop,
pub number_of_per_scenes_bounding_boxes: c_int,
pub per_scenes_bounding_boxes: __IncompleteArrayField<BoundingBoxesInterop>,
}Expand description
This structure extends on the basic statistics about an CZI-document, and includes per-scene statistics.
Fields
sub_block_count: c_int< The number of sub-blocks.
min_m_index: c_int< The minimum M-index.
max_m_index: c_int< The maximum M-index.
bounding_box: IntRectInterop< The bounding-box determined from all sub-blocks.
bounding_box_layer0: IntRectInterop< The minimal axis-aligned-bounding box determined only from the logical coordinates of the sub-blocks on pyramid-layer0 in the document.
dim_bounds: DimBoundsInterop< The dimension bounds.
number_of_per_scenes_bounding_boxes: c_int< The number of per-scene bounding boxes that are following here.
per_scenes_bounding_boxes: __IncompleteArrayField<BoundingBoxesInterop>< The per-scene bounding boxes. The number of elements in this array is given by ‘number_of_per_scenes_bounding_boxes’.