LibCZIApiErrorCode

Type Alias LibCZIApiErrorCode 

pub type LibCZIApiErrorCode = c_int;
Defines an alias representing the error codes for the libCZIApi-module. In general, values greater than zero indicate an error condition; and values less or equal to zero indicate proper operation.